
# q-expansion of newform 1250.4.a.n, downloaded from the LMFDB on 10 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1250
weight = 4
poly_data = [-45086320, 82757040, 78433160, -193725880, 14900696, 83435508, -11070230, -14035110, 1899751, 1143340, -151199, -47880, 6166, 990, -125, -8, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[-246199036512048478408023186494845472738280, 43592415860598142321513222204225446810600, 355215759083463672172019602978367449601780, 27418608768202620812488955377971677068480, -121258614206735892870779006788380048156050, -4955841075597817775053159224480902850320, 19451659006919605260059797040720617896381, -114037677041660259543130930625170867914, -1595083636278409773754961636429641821529, 63420377294206307807438746530988036812, 67580041586027164861044464273490798762, -4274381975720612921393707762243549644, -1409309606904377665774888046574651151, 113184032207733731831996632775585498, 11458748724136290787055843463663027, -1069464125100162760874994114577352], 5603291159985434938816495524295022572440], [[674632020803992772218504312, -1259773156528429963097166440, -1719061490662910410639523920, 1729263928096266435801236540, 1051303528391285401287874544, -439351209129842597187757728, -204154993827830505465902881, 50965673955785044487274117, 17848101691824502199050053, -3257047745667554042215933, -778037562329546807375568, 117849012148856420223872, 16522397332288035810951, -2253306920357720796683, -136292957292407835199, 17625511305178629155], 57181453573239074761611984], [[-5875465188252648721302663964660351242440, 3767714476876716949514239361102560634480, 15938213770601248540294604489659606488640, -7585375717329464357595908655447989263060, -8406109603019161061693668500585386733812, 2144281857622254150127684086430238692676, 1536970569933869326235307696843767833455, -277654602707779377821114763426484669888, -130002191542975375440089716490418978137, 19510950085628416395379326066228067450, 5539140695557685454396207598590903032, -752093617162397955429422339591987704, -115470603717990592474040073582634173, 14872850481759576487145306919999340, 936957767754206142941135541010775, -117797041579734287440895572047534], 273331276096850484820316854843659637680], [[895468469026884389449772106930940331884440, -297247586617071041096258758758755888685640, -2112159137481212595891295728087402195797840, 685362164285964770753665649533483350470860, 833379201946614448660369661818106604143956, -168695612466641039489011209819440560359408, -122559411302551252018313978056095147131709, 17807664173781619460119334277404615963405, 8767649503815782672902613668267653604677, -1027834385026494736389817354366478121813, -329486716082356727657242345685927714604, 34608399309534444410636029948144632608, 6275619019104687322492917745129756523, -639900769524642961522527337653075747, -47904186671572308715300113259431023, 4982685750591786789420540408217515], 11206582319970869877632991048590045144880], [[-30298046953018234914819829872853356997480, 5051702966234669902039097072552493439440, 50127245982626991632318381914707515531280, -12950366637676873484000678082590814172460, -25704721030214343509101461663434379219876, 3117121589851076412494584303812149962628, 4587294504796889492467285214504338122269, -382659571188430808465634401012949851980, -377164851650991885610116038376887521307, 28846099149373867460026963299918205458, 15623179167300487697763291778782489584, -1254072866913605887723363601555484368, -317916555323515174646584822828010823, 27901618554610719631015596693125432, 2532621941726194253851227693932293, -243688942197329839239135174807430], 273331276096850484820316854843659637680], [[1162311646692893325200389301419415007564040, 917545904204176276859874488607158780729760, -3140759437991286743189625583387944518989120, -156296119372914626715299557003579614995940, 1336547665174322064539739840326470007013976, -66963755033227134973100525069863257760048, -228633998056214944951598657559008341655489, 19757063889727468747118375502138135498910, 19095627173598718259154199969734847587607, -1956553779270407371427197809618790059108, -821466856065325636590873942833813020484, 90307268013095637001913987840291999228, 17439398471539341466549336915763550443, -1988327310336818964384480319401253422, -144490304525805199322801888494987153, 16904741661227646355570712424817700], 11206582319970869877632991048590045144880], [[1957031126341062081492090286630266702546720, -992669034296528260044361276943041851199800, -4817883627459669250122348594440287099699920, 1827375591108314924658910994596388634612280, 2237423872273932721438408256620406109631920, -454285406251684883637491109947893360765300, -370237481517761012346766454484621696774674, 51826136680698784864809396445080031367251, 28744972414254899122925485456553413814236, -3323364043483193486869517480587909025293, -1135757884323345278853062382616101709708, 121854996368902900148777923836321913016, 22167523979020769730631628599004816114, -2353984505865169327361990743937211417, -169940386149267259545126861711518048, 18432688368518010852483775494574123], 11206582319970869877632991048590045144880], [[-841174519412973735362248119832240466720440, 612439527586883938560374485525997006522120, 2771771121834210799110499407078878577538320, -1474066350035604143463718749805955281631100, -1397171421027228416224499336084520209113432, 442760636709979328847717005832223160454264, 249179439771144538748433099854510839424507, -58133613256575853920247264257020460007067, -20827238163453426287833689460305755508495, 3996591471027561178761373500226815883107, 880536324499863109186530747957669146552, -147728998048197103383532174909627035192, -18199904570360010210171847438447594397, 2777776247106471155492814574156896901, 146037738205990198117170871424288285, -20879704966685736566052415421346693], 11206582319970869877632991048590045144880], [[1761163574756325500950439895217624629718280, -131413936629237220277990750974908752866200, -4614156562511199163409784827686348597164080, 1511284538647774990070915132722035532492220, 2096583018902809769555839464393003652804580, -544620716478810822991233843417872874866500, -372390093640421537607752415097905278011751, 78644219242145268883440007057137854538199, 31979244309405125138135795882085509695039, -5742793954819218225825882000126281485307, -1406815256527351741839715346041633882092, 223100277237153335173757476110460782284, 30396214200510478206287601335153413361, -4408720865655947845216526656660109433, -255272751156302106122134068901980477, 34929171208073888019493149619988877], 11206582319970869877632991048590045144880], [[-1858685074638955818571232361878932573946240, 1252585537985058211839674569630384688258000, 4427202318110488530889390123520662771608260, -2370501644349463587074332962011885946793420, -2142983317602207115876138036009822476812256, 723314814285573230418745417906575496582320, 386144437356153357812038971792617331282607, -96185050962886909568431447859728465599336, -32931254679656953273168234538711819123589, 6650595042765878291941280145039183942546, 1425556883568307648540220028966074974084, -247261419219557634267202170605066591060, -30202355147084292941440505008703965989, 4694913550129491779499141963218542436, 248444101405326685017118438313257143, -35815184981891882761227650004703446], 5603291159985434938816495524295022572440], [[-1307772143193149926963381518514215951457960, 613295475071331206817710152919317072418020, 3015605523971300520895524011080699123858600, -1404603563866747961237527342204540741479010, -1414593841594535854946848808472130024461603, 436467641746070811746995940045693643018074, 250989120547588084907701127320673860017081, -58442883048512383532920423419039637385021, -21180569350713094472461229385705151480652, 4061106325256855718194245381957259173187, 909219838757315495010405421670240226385, -151656878418434004679348961399688625430, -19132194823777704430178061382980430063, 2890540681193301857710130363346402943, 156513696548082265152109780467635092, -22114709330151248158344459391550063], 2801645579992717469408247762147511286220], [[6397832932352110691876173384108245431900560, -3923615446733933605517111731124400938110600, -16536597715585073676720162237672423128093360, 8323525925059153685203668659135949261825120, 8119708722203691052159931094020964707680828, -2472494441874350637098754591724909489834820, -1440675210587403565650373775507300082839534, 320646188389041794565987152035757212950285, 120176777646940688082756490190911730360984, -21852436969228945655690573062948387471899, -5090257886055202447561375777749428111288, 808356151321676827190653755004607438512, 105838584730153748704345790090194374350, -15355244083472014736152337933148200567, -857433758016969263059435603390240620, 117451733351824900826577794999332069], 11206582319970869877632991048590045144880], [[4321069197055685595484914883391676837240, -2434183417286781746537223003903405872580, -10104393664921602622631756712569099952940, 5097052558089603661903924996488609443760, 4788775418832348466564845170751188325952, -1504359024277127953673722031288245639471, -837474708866429616110420978383698808555, 193552392946919303454961281807152425073, 69393716300896638590668415572293020677, -13080816284782169841336063918622012550, -2930704290534293045011681345222040672, 479956856115963595285001345166690409, 60861487714685060880888478177945233, -9048634601740397219583929250667915, -492762129799335008194934801374075, 68749390374322572604944472837314], 6212074456746601927734473973719537220], [[-1795022179033208745354462447932113467621520, 804284562367384592076252412968337718130760, 4623429385048770416620563593083323091533540, -2163364443778120876821080892187183140820510, -2229464179084444811798841839734765173366278, 674857721727583896724659786267819584957167, 395721192050854595519331096380416488364376, -89963181270824855703272550020321927849217, -33180431176286993971632322940969342790262, 6223637373399386343977577275702337772950, 1413153851957748689423178263004117368906, -231618340280317797947180035635506420125, -29510497940296196484836484353301128620, 4401622810494876749034855441006605763, 239757645813782841775855601205742998, -33576259405212958085687963827304828], 2801645579992717469408247762147511286220], [[-5603551945083809218303151957200584606774320, 3145130894857715235240929037929398404013480, 13343608268778718335039867723808765699699020, -6587146956166762919029142590651594130967080, -6396231542864710648600748068221821533488926, 1993840534346318482080822050223153638455646, 1133434714704299774602933550235841766549165, -262068517506575055063623805829048856628240, -94988770321618173139210128533680755492581, 17988846521454852077484957776254459941668, 4046995391170587659632163038577341129182, -666736646455866471750060220455538543222, -84591283965062382247769925899387858231, 12648698361735442142003281545130103900, 688155496548949169603813644441843631, -96468999845803454661929370354937712], 5603291159985434938816495524295022572440]]

hecke_ring_character_values = None
aps_data = [[2, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [1, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [3, 1, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [4, 0, 1, -1, 0, 0, 0, 0, 0, 0, 0, 1, 0, 0, 0, 0], [13, 0, -1, 0, 0, 0, -1, 0, 0, 0, 0, 0, 0, 0, -1, 0], [13, 0, 2, -1, -1, 0, 1, 0, -1, 1, 0, 1, 1, 0, 1, 0], [6, 1, 0, -3, -1, -1, -1, 0, 0, 1, 1, 0, 0, 0, -1, -1], [20, 0, -3, -2, 2, 2, 0, 0, 2, -1, -1, 1, -2, -1, 1, -1], [27, 3, 0, -5, -2, -2, 1, 1, 1, 1, -3, -1, 0, 2, 2, 1], [6, 1, -3, -5, 2, -2, 0, -1, -3, 1, 2, -1, -2, 2, 0, 0], [42, -6, -3, -2, -1, 0, 2, 2, -6, 3, -3, 1, -2, 1, 3, -5], [34, 0, 1, -6, 8, 1, 4, -5, 6, -6, 3, -1, 0, -3, 2, -3], [61, -2, -1, -2, 1, -1, -1, 2, 3, 5, 6, -5, 1, 0, 1, 3], [49, 4, -2, 6, -1, -3, -2, 4, 7, -5, -7, -2, -3, 0, -5, 4], [30, -3, 20, 10, 6, -3, 1, -8, 6, -6, 6, 2, 8, -1, 1, -3], [59, -5, 16, -15, -6, 0, -1, 7, 2, 0, -5, 4, -5, -6, -1, -5], [47, 1, -11, -6, 7, -4, 4, -1, -7, 2, -9, 1, -1, -5, -2, -3], [86, -4, -14, 16, -10, -5, -2, -6, -6, 5, 7, 3, 0, 0, 1, -2], [101, -8, -15, -28, -4, -5, -3, -5, -3, 10, 12, 1, 7, 1, -2, 3], [114, -10, 32, 50, -5, -9, 0, 0, -11, 9, 8, 1, 1, 2, -4, 3], [-1, -6, 35, -16, 0, -7, -2, 4, -15, 1, -2, 8, 1, 2, -3, -6], [157, 9, 12, 40, -5, 6, 0, -5, -2, 1, -7, 7, -6, 9, 7, 1], [188, -17, 28, -28, 2, 5, 3, -11, 6, -8, -7, 8, 11, -10, 11, 1], [248, -23, -32, 47, 5, -4, 5, -6, 5, -7, 20, -3, 11, 4, -7, 0], [264, -4, -41, 4, 1, 13, 10, 17, -12, 0, -4, -11, -19, -6, 5, 7], [301, -11, 28, 44, 8, 13, -11, -6, -5, -10, -3, 0, -13, 8, -8, -10], [69, -12, -40, 11, 0, -1, 6, -6, -22, -9, 3, 13, -4, -14, -1, 4], [103, -4, 28, -10, 16, 7, -13, -14, 11, -25, 33, -14, -1, -10, -11, 11], [197, -12, 83, 11, -14, 12, -4, -7, 2, 14, 18, 8, 12, 4, 10, 4], [242, 18, -90, 6, -8, -11, 15, 20, -4, -10, -23, -11, -16, -3, -2, -8], [284, -10, -78, 86, -8, 15, 6, -28, -18, -15, -18, 32, 14, 12, 35, -7], [329, -8, -86, 58, 1, 8, -1, 35, 21, -6, 28, -17, -5, -7, -21, 12], [-30, 17, 74, 115, -13, -11, -7, -17, 2, 7, 8, 8, 14, -23, -5, 14], [294, 24, 26, 93, -26, 17, -1, 14, -22, 29, -19, -3, 6, 42, -3, 12], [55, 27, -74, 73, -32, -11, -5, 2, -2, 17, -16, -4, 27, 11, 0, 27], [638, 13, -149, 144, 26, -5, 21, 24, 39, -11, -22, -7, 9, -10, 19, -5], [593, 36, 116, 55, 4, -34, -7, -16, -32, 19, -36, -18, -6, 21, -5, 40], [328, 46, -105, 38, -33, -37, 14, 37, 7, 3, -35, -8, -19, 3, -7, 0], [-106, 27, 155, 33, 0, -4, -8, -17, 6, 0, 8, 28, -30, -12, 10, -8], [-547, -13, 134, 41, 36, -8, 5, -12, 18, -4, 76, -46, 7, 13, -23, 36], [-552, 80, -57, 67, -36, -8, -18, 8, 25, -5, 36, -54, -21, 8, -25, 10], [-789, -34, 10, 75, -12, -48, 15, -13, -1, -55, -42, 6, 11, 9, -1, -12], [581, 7, 240, 58, 38, -3, 19, 9, 45, -41, 9, -58, -5, -14, -18, -16], [143, -70, -68, 50, 33, 4, 47, -43, -56, -62, -32, 54, -14, -18, 37, -52], [-1201, -7, -3, 67, 48, -22, -16, 31, 17, 0, -52, -14, -32, 18, -13, -29], [-1024, -3, -62, 169, -3, 45, -3, 39, -32, 13, -6, 4, -26, -25, -25, -30], [1347, -7, 73, 8, 27, 5, -54, -53, 6, -9, 21, 5, 32, -18, 15, 6], [678, 29, 0, -122, -15, -3, 21, -34, 7, 22, 57, 14, 69, 21, 68, 38], [-516, -64, -128, 114, 49, 40, 15, 19, 45, -38, -65, -22, -22, 38, 9, -15], [249, -128, 116, 106, 83, -34, 73, -3, -16, -30, -70, 26, -6, -28, -5, -46], [-947, 70, -91, 37, -78, -1, -88, 16, 40, 6, 36, -70, -4, 2, -34, 90], [-932, 1, 59, 120, 50, 28, 60, -52, 13, -29, 43, -8, -12, 13, 44, -25], [-1085, -18, 5, 222, 20, 6, 6, 58, -23, -6, -14, -30, -39, -6, -46, -7], [249, -114, 119, 98, 52, -17, 1, 76, 69, 3, 39, -30, -55, -17, -38, 2], [1053, 16, -225, -56, -27, 4, -67, -10, 78, -18, 5, -47, -14, -9, -40, -29], [-114, -100, -20, 106, 7, 48, 27, 51, 75, -14, 17, -18, -6, 0, 3, -13], [-1754, 91, 118, 145, -34, -5, -9, -6, -2, 58, 36, -65, 19, -11, 11, 40], [946, -75, -59, 185, 44, -34, -18, -91, 18, 12, 2, 46, 2, 4, -6, -16], [-41, -16, 110, -46, -10, 51, 6, -14, 57, -38, -16, 35, 13, 26, -40, -29], [2306, 1, -9, -104, -2, 77, 13, 81, 99, -52, -7, -36, -21, -67, -4, 42], [529, -26, -267, 190, -49, 80, -51, 17, -19, 19, 28, -35, 23, 81, 73, 16], [1346, 56, -90, -128, -10, 56, 58, 20, -102, 68, -68, 24, -14, 14, 48, -42], [-713, -99, 171, -31, 210, -19, 8, -42, 115, -55, 73, -34, -26, -37, 8, -7], [134, -79, 125, 316, 63, 26, 41, 22, -74, -72, 35, 77, 26, -37, 18, -31], [-1061, -28, -86, 99, 6, -34, -66, 20, 20, 62, -106, -28, -84, 54, -38, -12], [-1063, 4, 132, -10, 77, 52, -46, -26, 44, 2, 7, 12, -17, -55, -19, -28], [-1326, 98, 207, 80, 89, -59, 28, -89, 12, 33, 115, -29, -6, -72, 45, -16], [-1445, -105, 193, -87, 70, -124, 113, -27, 3, -183, -28, -69, 23, 25, -37, -12], [-330, 217, 91, 51, -102, -59, 61, 39, -74, 150, -19, 25, 43, 24, 115, 35], [-1192, -163, -105, 168, -8, 43, 53, 77, 41, -56, -27, -46, 41, -9, 36, -72], [-401, 129, -493, -255, -16, -63, -66, -36, 15, 63, -33, -2, 18, 43, 8, -47], [2151, 22, -248, -176, 29, 103, -20, -6, -43, -69, -13, -70, -119, 4, -59, 34], [-747, 90, 65, -76, 125, -82, 190, -106, 9, -67, 27, -82, 23, -39, 45, -13], [-1111, 63, 98, -429, -60, 124, 15, 12, 40, -48, 50, 36, 69, 13, -15, -32], [-1721, 7, -95, -592, -41, -65, -60, -27, -63, 43, -123, -40, -55, 87, -93, 108], [311, -159, 404, -257, 19, -3, -4, 126, -35, -71, 20, -18, 11, -40, -43, -65], [425, 113, 21, 96, -110, 70, -139, 8, 50, -20, 111, 63, 62, -4, -20, -21], [456, 84, -61, -352, 8, 6, -7, 35, -16, -20, 116, 18, -80, -29, -14, 6], [-672, 157, 486, -68, -50, 19, -18, 84, -46, 39, 11, 27, -73, 75, 56, -22], [1167, 9, -69, -154, 4, 55, 129, 73, 84, -61, -151, -9, -45, 2, -14, -44], [527, -135, -554, -280, 35, 34, 133, 0, 18, -79, -101, -24, 80, 64, 49, 65], [-925, -159, 297, -106, 188, 35, 169, -171, -134, 21, 43, 35, 5, -64, 98, -142], [-375, -96, 252, 158, -108, -35, 43, -14, 0, 2, -10, 184, 42, -13, 21, -13], [-1375, 23, -62, 349, -32, 122, 48, 122, -68, 113, 25, -37, 1, 63, 98, 26], [-2907, -149, 322, -244, 179, 31, 106, -55, -76, 68, 152, -136, -84, 45, -68, -3], [746, -130, 476, -236, -136, 38, -41, -114, 3, 28, 117, 22, 33, -36, 64, 82], [1107, 14, 20, 4, -78, 119, 27, 119, -78, 17, 24, -44, -92, -57, -121, -1], [307, 23, -128, 801, 128, -14, 159, -142, 65, -185, -166, 131, 28, 19, 124, -30], [1410, 69, -532, -780, -29, 93, -126, -120, 58, 67, -55, 127, 50, 83, 71, -26], [-1752, -146, -365, -356, -287, 55, -25, -9, -126, 68, -21, 153, 118, 3, 92, -4], [-1045, -188, -134, 782, 78, -94, 2, 140, 36, -153, -26, -17, -120, -218, -95, -83], [-534, -78, 399, -340, 86, -202, 28, 182, 80, -85, -221, -5, -64, 67, -135, -25], [2007, 40, 124, 1023, 14, 94, -28, 100, 35, 90, -16, -21, 61, -38, 28, 81], [-3221, -336, 89, -29, 15, 36, -56, 37, 16, -118, 90, -11, 47, -218, 15, 11], [-2871, 41, -228, -80, 23, -52, 85, -189, 17, 10, -51, -116, 161, 65, 0, 193], [543, -401, 140, 186, 251, 164, 137, -45, 156, -193, -36, 36, -62, -9, -25, -170], [1992, 183, -195, 1335, -116, -47, -132, 57, 156, -86, -172, -57, -79, 6, -163, 34], [2055, -3, -497, -682, -98, 68, -212, 18, 104, 201, 227, -11, 54, -79, 69, 1], [-288, -163, -517, 647, -66, -92, 55, 100, 10, 293, 366, -135, 131, 39, 24, 59], [-1245, 34, 528, -161, 34, 130, -4, 88, -208, -2, -138, 2, -242, -78, -116, -182], [-3201, 169, 93, 205, 132, 188, -73, -76, 235, -72, 55, -158, 69, -78, -72, 41], [-3934, 53, -387, 161, 60, -35, 104, -160, 70, -18, -66, -6, -42, 33, -10, 135], [3708, -202, -631, 653, 18, -40, 51, 73, -147, 58, -94, 185, -13, -37, 132, -61], [502, -312, 139, 896, 439, 64, 132, -36, 57, -296, -29, -66, -114, -83, 1, -85], [4069, -99, 879, 196, -153, 215, -94, -91, -118, 323, 87, 63, 72, 134, 99, -38], [-6127, -21, 400, 496, 153, -36, 67, 235, -14, 26, -57, 17, -28, 32, -120, 5], [-2123, -266, -690, -263, -2, -20, -38, 171, 118, 161, 221, 53, 30, -57, -23, -131], [3123, 348, -1008, 265, -130, -1, -220, -205, 175, -35, 177, 5, 183, -53, -117, 53], [2369, -359, -653, 43, -142, -125, -6, 23, -342, 37, -98, 110, -63, 8, 138, -27], [3005, -320, 1367, 2, 89, -129, -50, -282, 160, -26, 310, 148, 180, -10, -52, 17], [431, -46, -132, -412, -126, -239, 95, 140, -63, 158, -121, -96, -11, 47, -100, 140], [50, -47, -152, 188, 140, 45, -131, -160, 126, 178, -4, -34, 36, 127, -35, 141], [2629, 189, 248, 205, 40, 232, -123, -300, 86, 70, 166, 28, -25, 103, 129, 102], [-1079, -193, -563, 1666, 186, -31, 91, 159, -20, -75, -77, 33, 13, -190, -10, -48], [94, 85, 842, -538, 134, -43, 235, -66, -121, -63, -236, 207, -152, -303, 80, -360], [-1872, -15, -364, 446, 285, -90, 380, -56, -175, -256, -122, 105, -75, -82, 140, -72], [-431, -294, 103, -860, -176, 301, -125, 159, 47, -136, 143, -6, 171, 125, 116, -60], [-2325, 182, 334, 741, 206, -13, -22, -257, 12, -306, -160, -28, -242, -9, -162, 29], [2178, 700, -737, 103, -280, -52, -230, 266, 110, 180, 114, -139, 0, 16, -130, 170], [498, -126, -1583, 810, 133, -16, -58, 159, 285, -294, -140, -174, -176, 22, -125, -146], [2577, -186, -691, -25, -47, -99, 132, 192, 38, -118, -178, -14, 60, -87, 146, -85], [2778, 42, -1049, 147, -233, 123, -146, 102, -93, -46, -248, 81, -135, 83, -48, -59], [-3657, 261, 1356, 438, -115, -176, -44, 221, 272, 173, 187, -159, 56, 163, -97, 191], [-746, -206, -372, -49, 131, 307, -78, 208, -93, -23, 189, 45, 124, -59, 92, -4], [3277, 152, 349, 1303, 8, 151, 143, 196, 135, 95, -45, -91, -105, 80, 155, -173], [600, 228, 1066, 53, -124, -28, 1, 171, 346, 100, 52, -239, 96, 27, -164, 160], [-7500, 251, -916, 215, -106, -77, 90, 31, -26, 235, 132, -106, 161, 38, 204, 121], [1287, -63, 801, 142, -402, -304, -108, 74, -296, 239, -395, 75, 126, -73, -141, 55], [6971, 488, -181, 736, 391, 22, 155, -62, 331, -140, -93, -174, 103, -86, 40, 211], [-4843, 437, 120, -43, -56, -172, 307, 105, -48, 82, -645, 106, 101, -74, 43, -67], [-1949, 214, 430, -2140, -212, -35, -167, -255, -62, 169, -416, 230, 144, 131, 247, -25], [-7429, -182, 235, 707, 498, 264, 74, -127, 254, -549, 49, -118, -160, -307, -21, 122], [3056, 113, 836, -552, -248, -228, 67, 112, -316, 109, 97, 77, -66, 265, -50, 31], [2395, 65, 1272, 547, 16, 171, -419, -301, 105, 81, 293, -80, -86, 146, -306, 275], [-278, -183, 167, -1003, -42, 108, -121, -86, 273, -228, -162, -36, -96, 33, 9, -123], [3704, 189, 727, -783, -235, 81, -99, -184, -249, 71, -101, -4, 279, 330, 100, 48], [4284, 438, 808, -1636, -106, 293, -193, -144, -322, 92, 319, -239, -108, 175, 98, 176], [-2688, -33, -96, -61, 62, -13, -59, 49, 379, -377, 335, -170, -151, -120, -478, 114], [1625, -284, -852, 403, -122, -100, 513, 448, -92, -298, -125, -89, -8, -92, 142, -137], [1963, -254, -68, -1381, 94, -64, 122, -176, 57, 244, -154, 115, 629, 134, 278, 207], [3479, 47, 2674, 480, 403, -12, 161, 73, 219, -208, -212, -279, -153, -191, -78, 106], [4240, -190, -1940, 550, 156, -33, -199, 138, -380, 138, 331, -365, -244, 125, -194, 268], [2099, -247, -45, -317, 190, -128, 84, -189, 281, -196, 170, -35, 21, 128, -240, 110], [2267, 96, -202, 382, 170, 55, -159, -137, -407, 51, -42, -246, -307, 131, -7, -108], [1454, -839, -1654, 52, 610, 79, 138, -331, -41, -304, 166, -96, -290, -232, -159, -183], [1255, 231, -112, 745, -342, 68, -253, -210, -208, 227, 119, 45, 350, 59, 2, -23], [5795, 116, -434, -1756, -105, -16, -281, -128, -60, 443, -146, -46, -26, 172, -175, -176], [-2604, -401, -563, -10, 499, 74, 191, -446, 208, -408, 611, 159, 156, -282, 20, 32], [137, 43, 2509, -374, 130, 298, 380, -204, -172, -405, -565, 335, -96, -199, 361, -533], [511, 286, -306, -323, -343, 110, 8, 400, 205, -136, -11, -220, 297, -48, 125, 437], [5636, 287, -545, 909, 42, -140, 61, -60, -181, -6, -260, -176, -180, 193, 209, 359], [3792, -549, -608, -1733, -87, 71, -74, -75, -216, 98, -772, 374, 56, 43, 310, -21], [7299, -91, -2165, 600, -51, -159, 352, 481, -446, 173, -733, 241, -468, -42, 73, -306], [-573, -75, 1410, 553, 449, 67, 84, -24, 533, -573, 397, -690, -73, 36, -193, 128], [-6132, -372, 824, -326, -512, 181, -187, 160, -452, 244, -133, 375, 36, -118, 12, -33], [-5426, -60, -155, -1043, -672, -500, 225, 54, -240, 173, 235, -6, 248, 418, -47, 210], [8421, -367, -1421, -338, 732, 417, 166, -7, 935, -409, 248, -335, 298, -306, 22, -58], [4301, -659, 210, -345, 151, -21, 100, -571, -258, -348, 4, 270, 214, -240, 396, -283], [10808, -476, 383, -442, -355, -494, 192, -190, -344, -89, -159, -211, -43, 293, -190, 295], [-1770, 902, -2432, 729, 124, -45, -316, -103, 237, 2, 144, 33, -145, -7, -308, -31], [3250, -601, 752, -2251, -345, -108, -355, 62, 99, -271, 332, 115, 73, -196, -119, 36], [3590, 965, -8, 176, -443, -549, -228, 198, 61, 531, -133, -90, -81, -128, -157, 148], [-4477, -122, 2285, 728, 450, 345, 212, 506, 731, -711, -36, -350, -153, -254, 27, -254], [659, -807, -315, -1468, 708, 247, 5, -159, 259, -664, 286, -145, -505, 1, -245, -23], [4492, 49, 1088, -1628, -618, -124, -350, 117, -435, 705, 569, 344, 97, 349, -297, 103], [-3205, -16, 1035, 1185, -534, 159, -480, 288, 284, 170, 182, -66, -152, 632, -20, -62], [13269, -47, -906, -202, 115, -162, -104, -171, -40, 177, -297, -43, 48, -167, 27, 143], [1103, -158, 486, -923, 134, 315, -476, -770, -204, 399, 424, 221, 334, -230, 233, -69], [5825, -292, 1329, 337, 300, -362, 303, -107, -165, 179, 131, 420, 147, -199, 90, 27], [-640, -322, -3273, -1484, -285, -14, -452, 304, -237, 246, 239, -426, -542, -15, -533, 283], [6741, 75, -2246, 2213, 13, 177, 224, -45, 15, 253, 249, -30, 363, 131, 287, 12], [144, 506, 451, -1465, -186, -438, -157, 394, -86, -317, -1133, -92, -478, 256, -355, -72], [5052, -222, -1211, -1781, -435, -336, 289, 441, -473, -101, -130, -365, 203, -39, -53, 84], [-6356, -138, -771, 602, -568, -442, 13, -76, -105, 326, 825, 186, 731, -8, 358, 396], [4660, 281, -437, 36, 420, 211, -352, -101, 595, 50, 830, -516, -316, 316, -41, -147], [-6604, 282, 1909, 71, 16, -405, 34, -123, -308, 157, 205, 411, -246, -605, 157, -204], [7857, 37, -1499, -544, 880, 171, 457, 187, -179, -412, -499, 290, -646, -668, 43, -400], [7456, 554, -1373, 1226, -650, 182, -186, -28, -610, 191, -189, -45, 152, 397, 115, 75], [20596, 505, -1938, 1592, -452, 345, -223, 220, 276, -158, -248, -168, 65, 689, -231, 436], [6705, 391, 224, 996, 329, 392, 3, -345, 694, -290, 99, -307, 28, 336, -340, -115], [5029, -109, 1718, -406, -159, 160, -387, -420, 29, -98, 853, -263, -15, -120, 162, 179], [15394, 593, -2422, -1929, -281, -7, -86, 70, -6, 327, 207, 19, -84, -314, 49, -52], [12648, 44, -1694, -435, -355, 31, -208, 91, -67, 222, 444, -315, -43, -261, 92, 199], [-3311, -304, 1328, 1038, 174, 196, 96, 549, 645, -533, -13, -120, -509, -643, 43, 21], [12859, 238, 663, 2434, 268, -491, -210, -405, 127, -213, 423, -292, 155, -175, -443, 441], [8988, -1286, 47, 67, 835, -284, 575, -131, -481, -613, -44, 485, 69, -85, 37, -384], [7616, 665, -2561, -386, 318, -293, -94, 189, 81, 507, -329, 84, 175, -114, 75, -182], [1095, 484, 542, -78, -370, 214, -11, 106, 101, -865, -751, 121, -255, 128, -451, -149], [1098, -605, 107, 1080, 508, 267, 434, 352, -60, -433, 785, -307, 347, 95, -44, -88], [22111, 40, 302, -2852, -203, 387, -196, -884, -295, 5, -7, 220, 157, 324, 595, 80], [2140, 602, 1120, -1454, -628, -333, -303, -292, -58, -52, 503, -393, 500, 93, 430, 752], [8864, -586, 1317, -3201, -700, -214, -160, 707, -336, -138, -737, 209, -586, -217, -834, -235], [7117, -987, 3191, -31, 114, -458, -402, -453, -58, 460, 1220, 90, 397, 324, -175, -168], [-3440, 1453, -1543, -376, -512, -353, -288, 645, 371, 307, -869, -300, -267, 752, -485, 352], [9311, -976, 1364, -2652, 76, -160, -58, -44, -337, -108, -1037, 518, 203, -375, 67, -27], [10869, 1012, -882, 3275, -512, -71, -71, 674, 351, -438, -639, -516, 155, -490, -64, 556], [9234, -380, -1259, 69, 632, 91, 289, -306, -500, 775, 67, -169, -12, 88, 694, 118], [2209, -4, 78, -2752, 235, 148, 259, 597, 826, -248, 232, -642, -732, -182, -509, 38], [-2714, -143, 3820, -122, -309, -139, 158, 590, -860, 501, 319, -533, 40, 297, -519, 432], [18332, 316, 1181, -1111, -3, -49, -115, 572, 251, 413, -424, 503, -160, -119, 424, -451], [-363, -27, -263, -3522, -158, -99, 333, -499, -106, -395, -465, 101, 569, 16, 502, -2], [24738, 87, 660, -514, -257, 631, 31, 774, 771, -676, 191, -60, -43, -125, 2, 430], [1390, -103, 1966, 2482, -136, -319, 550, 1300, -676, 222, -209, -422, -139, -515, -93, -293], [-9455, 999, 604, -2074, 549, -284, -127, -822, 331, 234, 267, -341, 229, -10, 42, 673], [4340, 92, -1958, -2142, -380, -214, -177, 73, -982, 662, -279, 105, 194, 582, -36, -151], [2732, 416, -769, -29, -168, -162, -646, -495, 184, -710, 47, -93, 2, 237, -66, 915], [-8688, 1035, 213, 557, 306, 301, 251, 566, 626, -621, -86, -748, -60, -186, 403, -211], [10873, -208, -1332, 1765, -272, -369, 40, 294, 492, -477, -1260, 247, -290, 18, -263, 193], [-5370, -644, -334, 1704, 236, 95, 346, -379, -1048, 327, -201, -38, -428, 665, 333, -164], [-1898, -450, 2538, -4878, -418, -208, -326, -477, -282, 595, 1186, 312, 882, 0, 440, 266], [16882, -89, -1784, -533, 557, -246, 259, 488, 646, -462, -407, 376, -600, 10, -304, -512], [16102, -467, -2209, -1578, 37, -532, 327, 424, 425, -176, 499, -598, 193, -88, -4, 271], [-4032, 197, 95, 1593, -294, -198, 257, -236, 176, -458, 913, -319, -18, -590, -228, -35], [11324, -350, -2455, -327, -1014, 106, -14, 387, 18, 476, 611, 5, 802, -383, 266, -41], [2545, -453, 3572, 38, 1086, -59, 127, -1233, 450, -148, 1559, -178, 335, 144, 383, -321], [-3118, 1075, 5284, 2654, -230, 76, -392, -851, -516, 161, 137, 651, 140, 214, 381, -219], [16000, -1079, 2881, -2984, 0, -21, 113, -206, -241, -370, 26, -112, 252, -313, 17, -353], [-12424, 280, -4589, 3878, 30, -342, 626, 12, -523, -95, -311, 74, -9, -434, 671, 257], [-13066, 650, -421, -118, 341, -74, -974, -514, -164, -733, -463, -325, -408, 161, -869, 501], [5634, 497, -5070, 849, -811, -307, -999, -615, 79, 50, 542, 83, 85, -413, -426, -134], [16743, 72, -222, 255, 170, 509, 307, 1372, 531, 236, -223, -662, -649, -592, 170, -210], [30705, -1042, -310, -4723, 22, 176, -142, -178, -313, -10, 1074, -243, 441, 332, 70, -273], [8079, 612, -2508, 2978, 1095, 611, -108, 994, 1158, -575, -53, -281, -314, -381, -271, 580], [-6340, 741, -1770, 2000, 377, -953, -253, 272, 1087, -18, 811, -1116, 587, -71, -374, 460], [2332, 222, 1408, 99, 1605, -83, 814, -1430, 330, -872, 1363, -208, 339, -413, 291, -750], [8119, -649, 3518, -1552, -374, -144, -68, -1, -488, 697, -824, -110, 408, 88, 452, 200], [-17765, 756, 2615, -355, -358, 959, 302, 682, 64, -240, 14, -568, -628, -186, -734, -68], [-2892, 511, -1347, 2260, -958, -247, -633, 873, -209, 204, -989, -762, -549, 521, -696, 1212], [-5647, -806, 4316, -1254, -1051, -433, -80, -80, -1218, 841, -415, 656, 499, 465, 824, -199], [1130, 1625, -5154, 2415, 441, -378, -724, -276, 392, -566, -542, -418, -594, -222, -278, 172], [12096, 1034, -942, 1190, -880, 623, -306, 373, -28, 733, 405, 132, 942, 55, 529, -552], [-16568, 391, 625, -1417, -1000, -234, 21, 476, 511, -118, -354, 558, 536, 585, 67, 1211], [-1527, 360, -2435, -4716, -1128, -1457, -613, -150, -988, 1807, 19, 124, 172, 696, -369, 528], [15036, -673, -6358, 2228, 95, 605, 360, 396, 103, -467, -311, -410, -243, 314, 569, 24], [1230, 65, -963, 1352, 245, 560, 559, 478, -328, 862, -333, -251, 326, 685, 1410, 15], [-6002, -834, -301, -2650, -126, -474, 51, 529, -926, 639, -962, -3, -824, 557, -789, 353], [-27480, 55, 3245, 2494, 1605, 396, 926, -771, 840, -434, 615, -749, 38, -216, 355, 45], [-21472, 619, -2023, -4003, -998, 463, -105, -44, 297, -701, -644, 530, -86, 289, 414, 206], [-19174, -942, 295, -1632, 82, 600, -1015, -1012, 83, -818, 209, 218, -277, -256, -218, -244], [-8861, -37, 2923, 2035, 1006, 1120, 778, -111, 1823, -936, 632, 533, 115, -604, 1036, -736], [11924, 929, 1593, 603, -478, -720, 127, 674, -799, -20, -350, 18, -264, -705, -351, 703], [3092, -360, -398, -460, -221, 249, 512, -631, -258, -820, -516, 148, 402, -525, 64, 305], [301, 883, -996, -1490, -434, 170, -978, -542, -290, 978, 529, -155, 929, -673, -175, 461], [2475, 357, 34, 1188, 627, -419, 1132, 96, -40, -1171, -28, -664, 128, -271, -224, -401], [-28037, -1333, -3928, -2471, -900, -148, 666, 202, -934, -343, -79, 139, 667, 189, -128, -220], [-13891, -894, 5056, 252, 18, 332, 522, -553, -223, 179, 1755, -74, 413, -247, 405, 665], [-15222, 500, 7755, 1132, 651, 0, -284, -640, 45, -40, -723, -132, -314, 79, -509, 453], [-13094, -704, 3651, -3036, 631, 506, 192, -1212, 629, -618, 465, -36, 1042, -41, 1001, 395], [-4790, 890, -1199, 2086, -246, -418, 828, 192, -1491, 637, -1117, -188, -621, 230, 323, -65], [17270, -1108, 3757, 2313, 353, 488, -253, -605, 355, -701, -556, 585, 357, -127, -223, -72], [-13000, 1075, 2014, -4056, -654, -612, 22, 217, -858, 868, -1384, 157, -59, 788, 485, 716], [-5683, 539, 3199, 2510, -348, 851, -885, -30, -288, 307, 1018, -470, -114, -288, 79, -137], [-5806, 437, 3117, -1862, 1388, -1089, 148, -873, -237, -51, -952, 185, -1066, 32, -28, -512], [4632, 593, 1112, 4440, -527, 927, -1427, 1314, -383, 538, 315, -638, -229, -255, -1564, 322], [5427, 9, -1374, -4343, 1312, 532, -265, -1402, 692, 394, 696, 4, -413, -237, 67, -308], [12279, -94, -7487, -4257, 457, -27, 138, 422, -95, -70, -1267, -940, -836, 149, 423, 237], [-2758, 838, 2750, 1644, -526, 903, -383, 1162, 138, 88, -341, -813, -244, -719, -670, 236], [-4741, -385, -1823, -3756, -124, 557, 1040, -127, 54, -613, 1555, -661, -66, -414, 27, 0], [2864, -618, 4104, 1439, 1667, 1024, 903, 725, -18, -492, 789, -971, 436, 17, 34, -221], [-1859, -1235, -6555, 414, 501, 201, 652, -1429, -218, -1375, -653, 849, 406, 376, 523, -508], [2611, 343, -2307, -4216, -184, 898, 47, -154, 564, -588, 791, 49, -366, -270, -142, -607], [-3202, -1305, 3083, -5195, -379, 485, 312, -185, 440, -1231, 719, -180, 870, -19, 1013, -37], [22254, -937, -3290, -1460, 150, -376, -1139, -1374, 308, 531, -219, 697, 38, 775, -184, 227], [-5917, -412, -1804, -1339, 101, 522, 667, -624, -429, -637, -1324, 5, -427, -28, -13, -182], [4999, -1601, -2584, -1734, 561, 69, -551, -915, 69, 971, 1544, -113, 291, -245, -165, 291], [-17639, -259, 1951, -1845, -714, 374, -1434, 574, 544, 536, 299, 292, -271, 341, -597, 489], [-34040, -1010, -1938, -3131, -1396, -987, -462, -384, -1128, 219, -422, 723, -176, 238, -509, -1101], [-2009, -1175, -3002, 2279, -823, -306, 807, 306, -1065, 155, -1036, 259, 819, -491, -39, 194], [-11642, 121, -7112, 141, -272, -241, -669, -237, -605, 1155, 67, 550, 1233, -564, 428, 138], [-7188, -758, 3603, 4920, -538, 819, 737, 1600, -1104, 1105, -201, 26, 154, 86, 13, -2], [17736, 2641, 2387, 2796, -1410, 99, 53, 1331, 787, 1168, 1219, -796, 959, 927, 480, 1668], [9781, 13, -5927, -6146, 231, 476, -671, 452, 582, 126, 114, -706, 90, 189, 155, -154], [-15602, 1318, -519, -2530, 740, -6, 155, 632, -1537, 936, -1351, -708, -803, 370, -566, 200], [22381, 1466, 7444, -4767, -142, -699, 817, -351, -874, -641, -1008, 344, 688, -168, 305, -211], [-14018, 787, 783, 4578, -449, -870, -121, 218, -41, 628, -585, 572, -503, -448, -166, 71], [-22377, 1009, 5384, 1820, -73, 772, -1209, 623, 990, -774, 1135, -163, 442, -166, -402, -125], [3302, -2847, -3285, 1873, -430, 604, 229, 480, -2478, 401, -252, 1367, 11, 359, 860, -1159], [29781, -2673, -5973, -3221, -152, -136, 497, -551, -802, -1090, -1139, 164, -415, -276, -157, 321], [-32543, 1095, 920, -1449, 68, -1542, -149, -1135, 668, -568, -853, -1016, -569, 910, -1087, 471], [-4966, 864, -4175, -1462, -361, -1143, 58, -1207, -668, 685, -29, 761, 988, 796, 267, 458], [-19949, -2496, 423, 3104, -1480, -623, -447, -413, -2205, 1564, 220, 501, 1333, 25, -132, -157], [4422, -994, 716, 4220, 145, -40, -683, 677, -2147, -120, -1005, -762, -265, 327, 96, 157], [4334, -1184, 2631, -3036, -1996, -1143, -1275, 1060, -538, -367, -629, -298, -144, 362, -1135, 54], [7224, -1395, -3895, 6642, 732, -293, 93, 641, 1093, -1448, 537, 150, -349, -797, -498, -1346], [-18426, -161, -5111, -4995, -568, 404, -691, -522, 253, 1160, 2070, 738, 1518, 465, 519, 55], [4282, 457, -2843, 102, -544, 1196, -64, -662, 543, -283, 2230, -595, 233, 36, -382, 254], [-23470, 1953, 737, -2038, -1770, -630, -426, 122, -649, 1615, 35, -106, 575, 723, -9, 291], [-30646, -1813, -3067, -231, -1054, 354, 1636, -803, -1175, -443, -846, 1339, 628, 574, 1238, -300], [-1622, 1743, 3913, -3084, -500, -589, -476, 497, 907, 365, -96, -1755, 836, 684, -334, 1104], [-40708, 145, -4502, -2282, -270, 500, 193, 1406, 1286, -497, -50, -84, -365, 485, 248, 815], [-39216, 242, 3916, -309, 164, -406, -260, 939, 1, -113, -313, 944, -1243, -993, -715, 5], [-18446, 9, -5541, -3997, 16, 308, 590, 603, -1302, 2470, 704, 1296, -172, 520, 1246, -1130], [-22155, -975, 4612, 841, 718, 1434, 275, 1030, 110, -580, -2180, 1448, -935, -5, 641, -608], [13735, 1265, 2025, -3144, 869, -672, -548, -1046, 499, 375, 2134, -467, -47, 273, -262, -486], [5674, 2286, 1573, 3412, 1032, 1754, -387, -1457, 1288, -1324, 990, 230, -364, -503, -44, -18], [7826, -17, 3098, 6816, -432, 1700, -1360, 236, 2083, -427, 1553, -294, 822, -743, 118, -43], [-24448, -362, -3454, 1649, 1140, 180, 1287, -620, 1705, -2307, -1106, 1139, -631, -443, 913, -458], [-1035, 2238, -1064, 2473, 1126, 34, 1018, -311, 469, -1246, -539, -299, -945, -539, -166, -274], [21683, -2440, 7866, 2384, -1058, 420, 279, 163, -695, -146, 147, 808, 487, 108, -448, -285], [-2719, 2884, -2180, 3496, 30, -1162, -734, -662, 505, 348, 197, -34, 985, -47, -887, 153], [-24890, -1133, -4985, -983, -1936, -104, 499, -43, -648, -15, 828, 216, 66, -245, -109, -588], [-28798, 598, 4319, 288, -1974, 699, -2349, 361, -471, 2069, 1384, 632, 181, -135, -1161, 298], [-24675, 141, 2300, -8204, -741, -360, 576, 279, -128, 867, 353, -981, 1096, 1285, 33, 1257], [-17271, -1119, 1953, -806, 862, 365, 595, 780, -1048, -1037, 456, 101, -595, 251, 176, 285], [16464, 1612, 7031, -886, -701, 424, -5, -580, -2724, 1230, -1988, 1712, -364, 591, 647, -160], [5125, -1439, 5221, -1298, 1498, 760, 128, 1340, 796, -727, -771, -571, -910, -1307, -411, -167], [24070, 453, 5337, 2033, -570, 256, 195, -1143, -724, 763, -1173, 1013, 219, 606, 476, -848], [-28049, -700, -177, -3899, 2340, 951, 1250, -182, 1056, -2004, -138, -952, -308, -538, -66, -180], [32417, -961, -2393, 3099, -954, 714, 195, 995, 915, -291, -104, 1227, 871, 109, 1199, 738], [-18450, 1687, -467, -382, -1929, -1034, -2007, 1962, -390, 1186, -1209, -939, 330, 1497, -1868, 2177], [-8816, 1897, -215, 2873, -1648, -560, 305, 808, -281, 692, -140, -320, -1080, 629, -285, 927], [13029, 129, -635, 348, -2286, 1066, -656, 938, -1313, 657, 365, -616, 518, 1267, -678, 1617], [54256, 174, -3212, -1599, -1244, -247, -350, -371, -851, 1006, 2574, -345, 2457, 859, 226, 603], [-20491, -2369, -5378, -166, 1050, 849, 445, 1638, 1190, -1650, 777, -1327, -366, -71, -790, -14], [38185, 1101, 3382, -271, 818, -888, 865, 108, 415, -773, -748, -1473, -1232, -765, -446, 586], [-25150, -1199, -738, -1857, 209, -522, 231, -202, -1688, -590, -1135, -326, -186, 124, -424, 460], [-26131, 1421, 941, -2185, -1242, 741, -674, 1914, -729, 695, 475, 268, -268, -177, -26, 767], [49786, 1315, -631, 3107, -1292, -514, 168, 1403, 828, -260, 1196, -1666, 182, -696, 380, 396], [-33990, 541, 153, 1721, -392, 253, -846, 1949, 892, -158, 440, -1237, -221, -672, -1073, 558], [5031, 705, -493, 5987, 441, -1373, 557, 142, 1373, -1349, 455, -2368, 319, -1194, -1771, 1052], [13386, -99, -3061, -5480, 3151, 825, 1242, -1135, 203, -1125, 834, 639, -187, -1529, -240, -1551], [-7945, -489, -2816, -2601, 1013, -811, 1038, 338, -67, -1165, -1274, -402, 131, -692, 359, 253], [-4535, -1810, -519, -504, 938, 1474, -158, 509, 294, -870, 1136, -452, 298, 169, -192, -24], [4589, 2617, 3806, -2517, -1940, -484, 562, 656, -423, 1028, -1604, 1765, -55, 1306, 1482, -166], [26296, -1529, -7534, -32, 784, 1133, 1611, -733, -484, -296, -151, 1244, 647, 878, 1277, -1335], [10072, 2063, -4593, -3580, 1659, -572, -939, -463, 2378, -556, 126, -745, -140, 359, 390, 303], [27689, -883, -1406, 6549, 921, 1186, 590, -762, -677, 414, 90, 367, -255, 624, 616, -614], [-12124, -1574, -7508, -552, 1753, 565, 1084, -903, 300, -1014, -516, -268, -1324, -1265, -902, 163], [-24555, -1419, 6466, -1206, -548, 1426, -54, 1357, 1193, 1839, 640, 1215, 1077, -239, 1888, -370], [11792, -1090, 1075, -6470, 454, 1107, 501, 2383, 1924, -1231, 194, -1824, -828, -665, -665, 1493], [6777, -46, 5261, 2038, -1750, 626, -225, 524, -1096, 1656, -970, -258, -1492, 1328, -599, -816], [-36402, -1062, -216, -2500, -678, 401, -293, 474, -96, 1894, 1757, -909, -136, -482, 332, 1189], [-18214, 416, -232, -1922, -700, 222, -1972, -148, -58, 1094, 1830, 60, -362, -6, -946, 1236], [2158, 111, -770, 7126, -344, -1028, -1575, -777, 1497, -666, 249, 1179, -44, -976, -1857, -678], [-553, 1577, 2567, 3959, 246, -146, -743, -1085, 205, -1085, -558, -241, 603, 285, 459, 1474], [10733, -1428, 2989, -3364, 178, 1049, 372, -1393, 352, -124, 1923, 687, -274, 501, -208, -1067], [-1182, -1339, 5570, -766, -2073, 28, -1505, 325, 263, -40, 2178, -31, 217, 89, 481, -50], [18827, -2385, -6132, -7700, -1158, -1781, -709, -627, 92, 466, 597, 920, 1445, 334, 341, 2245], [22768, 2080, -2434, -878, -1672, -981, -95, 942, -2594, 3512, -2395, 827, -400, 929, -350, -388], [26596, 575, 1065, -405, -1146, -613, -921, 1965, -1550, 2368, -1903, -515, -180, 969, -684, 572], [42443, -189, -2301, -4196, 1989, 167, 710, -203, -905, -105, -1511, 944, -819, -737, -71, -486], [-34359, 1782, -3854, -6298, -3302, -957, -577, -630, -1057, 75, -1375, 1692, 1563, 1310, 317, 1609], [-5966, -1941, -4708, -5290, 954, 195, 1060, -937, -847, 732, 278, -182, 346, 646, 889, 531], [22581, -2990, 2250, 1134, -262, -761, 496, -138, 233, -1015, 527, -478, 79, -1272, 571, 362], [13011, 559, -803, -4051, 273, -1121, -459, -1601, 389, -691, 1716, -222, 1355, 419, -121, 517], [29512, 1771, 756, -402, 790, -2129, -107, -1405, 112, 976, -2073, -764, -1349, 1582, 569, 795], [37, -1351, 11538, 4922, 2393, -204, 2094, -349, 1700, -3313, -1099, 29, -764, -1447, -315, -1777], [-57029, -1054, 2659, -6829, 606, -556, 579, 430, -834, -316, -979, 885, -846, -16, -1150, -1121], [-15896, -1268, 3677, -1096, -270, 412, 1134, -1845, -285, 574, 1163, 900, 1053, -456, 1709, -1047], [2827, -2802, -410, -149, 3110, -2188, 1040, -2103, 97, -678, 405, 853, -159, -245, 416, -932], [19647, 982, -952, -1320, 2685, -476, -1243, -1187, 1809, -1496, -144, -61, -2409, -155, -847, -564], [-10151, 264, -4754, 1879, 1436, 154, 1954, -994, -624, -1979, -956, 300, 308, -384, -489, -1397], [-13376, -658, -3877, 5250, 1682, 846, -218, -2532, 2073, -1447, 55, 562, 653, 480, 1329, -69], [38719, 467, 6045, 28, 276, -503, -1021, -1554, -1480, 793, -622, 1009, -173, -1185, -10, -2319], [-26067, -1261, 7385, -4966, 863, 739, 2584, 186, -393, -408, -2671, 1128, 65, -623, 1743, -1166], [-6622, -1199, 2675, -4680, -2714, -1101, -1301, 457, -1318, 1112, 773, 670, 1575, 1830, 103, 605], [10830, 383, -1120, 4330, 586, -1193, 201, 136, -175, 359, -1378, -131, 434, -1211, -210, 1404], [12839, -611, -8346, -9411, -222, -1958, 176, -516, -437, 896, -1038, -391, -465, 978, 714, 1634], [71961, 1412, 6709, -3718, 443, -734, -55, -378, 488, -282, -2605, -1273, -1016, 479, -916, 533], [51017, -561, -4232, 949, 2299, 887, -433, -1067, 603, -523, 1230, -1495, 595, -780, 449, 915], [8056, -231, -1653, -1554, -1046, -1000, 187, -1363, -1729, 1730, 1477, 157, 1156, 554, -581, -566], [1461, 618, -6609, 1106, -1019, -546, -897, -534, 565, 736, -759, -218, 795, -686, -1810, -261], [-18205, -3195, 3716, -1800, 273, -1706, 351, 34, -401, 294, -917, 619, 1, -536, 1424, 835], [28821, -374, 5015, -4115, 1365, -216, -85, -3043, 422, -1217, 1420, 630, 2, -335, 1473, -1022], [4417, 684, -7751, -7275, -4670, 294, -1834, 1585, -910, 1576, 802, 744, 2676, 2, -212, 430], [40697, -921, -7361, 5268, -605, -1734, 893, 2214, 805, -24, -2568, 355, 585, 874, -57, 306], [-7592, -1221, 9318, -10536, 1736, 380, 1002, -1199, -997, -841, 1573, -372, -721, -571, 381, -703], [3870, 2671, -7363, 2327, -1154, -874, -847, -243, -808, 1557, -123, 2933, 563, -126, 742, -190], [-21823, -744, -532, 232, 181, -856, 300, -1226, -762, 518, -1849, 264, -1095, 659, 867, -2562], [50300, 617, -3339, 279, -98, 1398, 1591, 925, 1655, -1876, -803, -612, 802, -1358, 1361, 1056], [-1240, 859, 3464, -5190, -1669, -972, -1453, -2350, -1094, 869, 1146, 1026, 1308, -694, 975, -908], [-32320, -2291, -530, -676, 1962, 1110, 955, 1427, -25, -2576, -1393, -2145, -2216, 272, -1139, -754], [16489, 1773, -2867, 43, 2128, 664, 24, 79, 3777, -1786, -138, -702, -282, -1312, 823, -75], [40082, 517, 306, 563, -1179, -1384, 800, 1441, -1872, 1307, -41, -2197, 1068, 267, 337, 1705], [-31111, 1478, -161, -4531, -2011, -1083, -744, 843, -902, 2033, -250, 1239, 1433, 978, 578, 136], [-34955, 1524, -768, -3667, 502, -100, -43, -1785, -727, -251, -60, -438, -43, 741, 11, 1718], [56689, -129, -5309, -671, -1484, -1324, 308, 1018, -742, -571, -101, 1005, -1784, -8, -1307, -831], [25859, 2057, -376, 4179, 352, -116, 1241, 32, 453, -239, 174, -1789, 660, -2003, -650, 586], [50246, 610, -10566, 763, -191, 445, 76, 41, 819, 250, -1576, 263, -1041, 881, -1052, 73], [-9782, -1455, -1665, 2847, 2104, -46, 2091, -2420, -1553, -382, -670, 422, 684, -7, 601, 747], [-2199, 2035, -3452, 6083, -2545, 91, -2290, 1949, 791, 1800, 368, -2911, -1069, -261, -3038, 1351], [34114, 1265, 1966, -5446, -99, 1877, 422, -530, 1457, 213, 1397, 202, 1597, 906, 935, -124], [18963, -2033, 2780, 3824, 1145, 1562, -633, -3586, -1309, -533, 1753, 1562, 1637, -649, 838, -1469], [25645, -1727, -1807, -2117, 763, -497, 2101, -801, -4523, -1187, -2032, 390, -1573, -233, 423, 127], [-10924, 969, -1853, 616, 1410, -173, 937, 1991, 1154, 142, -771, 671, 192, 1160, -558, 260], [-34407, -1854, -4852, 2980, 3012, -1168, 1558, -394, -1170, -361, -2716, 413, -1586, -756, 1009, -2397], [26188, 2354, -1723, 6031, 1985, -880, 2578, -2223, 395, -56, -1060, 579, 2123, -668, 1370, 848], [36498, 426, 4079, -4202, -403, -3203, -745, -1767, -1698, 2528, -2577, 2089, 1968, 499, 1090, 152], [43250, 3153, 6539, 2902, 741, -1312, -261, -984, -1222, 126, 1521, 603, -884, -513, -1410, -245], [-29124, -1321, -3128, -6832, -1438, 950, -635, -1322, 1488, -870, -1900, 2573, -381, -323, 453, -1902], [81059, 453, 2849, 6105, -1158, -1685, 67, 331, -1409, -366, -1465, -1716, -1537, 567, -2022, 1262], [-13912, 2709, 4314, 5694, -406, -602, 1279, 2309, 995, 552, -795, -1375, 578, -498, -447, -40], [31726, -450, -4081, -6405, 373, 278, 1097, -846, 657, 1886, 823, 1870, 2485, 326, 1514, -507], [-2749, -848, -11868, -2659, -3240, -184, -300, 852, -3823, 5378, -130, 169, 1967, 2288, 1850, 705], [19960, 557, 2651, 4474, -2370, 1036, -1526, 922, 695, -1383, 148, 1027, -939, 142, -402, 172], [-10076, -919, 1070, 12769, 2798, 1481, 3423, -270, -904, -2208, -1524, -241, -2797, -823, 129, -2648], [-8335, -482, 428, -1646, -1528, -330, 299, 858, -505, 879, -1757, 1767, -65, -672, 1917, -363], [10092, 1160, -5959, 2146, -2811, 1110, -1592, -1258, -2935, 3234, 1301, 1470, 3888, 1947, 1839, 753], [-31389, 923, 2167, 8330, 1668, 1085, 345, -3116, 328, -2157, -1286, 3057, 115, 625, 1864, -993], [-9696, 1950, 1766, -1, 49, 1430, 774, 2328, 2754, -709, -105, -3422, -175, 493, -1942, 1045], [-32245, 278, 9516, -1866, -2969, 2038, -1929, 3243, 1986, -314, -542, -348, -136, 340, -2075, 814], [11842, 3328, 6676, 992, -2455, -792, -1155, 1647, 101, 3402, -2329, -664, 571, 1497, 474, 2771], [24762, -528, 6854, -6130, 3288, 98, -104, 249, 245, -775, 136, -1725, -1487, -771, 104, -1044], [5947, 2487, -8867, 15850, -446, -131, -157, 744, -1990, 405, -1314, -73, -2401, -53, -1148, -903], [-16564, -3696, -4656, 2228, 1990, 459, 251, -586, 4306, -1726, 4253, -1285, 1206, -458, -796, 365], [81308, -1852, -499, 2832, 728, 157, -616, -933, -1183, 915, 596, 1021, -141, -206, -616, 463], [8194, -374, -8873, -168, -2218, 1580, -926, 466, -140, 2361, 890, 155, 1414, -882, 1367, 131], [117098, 1003, -7568, 731, -1177, -133, 16, 887, 1662, 1106, -776, -318, 1372, 551, 1224, -17], [-6809, 1301, -13757, 5760, 240, -301, 2113, 1099, -1474, 1779, -669, -1121, -281, 932, 1794, 78], [78898, -1483, 4449, -674, -2137, 504, -953, 1714, -993, -1808, 475, 496, -357, 740, -1500, 265], [-33402, -4101, 855, 9938, 3696, -1503, 2360, -1459, 1839, -3507, -471, 1418, 1045, -342, -983, -1674], [1800, 2103, -359, -7423, -2704, -1372, -827, 770, -1002, 1500, -2519, -1139, 666, 1990, 988, 315], [24441, 3707, 14637, 5505, 545, 742, -909, 806, 1855, -1048, 1959, -1296, 187, -804, -1374, 377], [-30551, 1948, 6937, -4870, 2088, -505, -979, -282, 49, -1713, -945, 662, -2907, 1461, -1122, 558], [4083, 1539, 12673, 8983, -279, 1959, -1751, -989, -913, 287, 1706, 674, -309, -307, -827, -201], [-39590, 848, 4281, 2373, 2234, 646, -1325, -1304, 2264, -1171, 351, 120, -912, 412, -1111, -2314], [6297, -1359, -16231, -10222, -2044, 908, -860, 1566, -302, -409, -1063, 1501, -1296, -1889, -917, 1231], [-16820, -2811, 4897, -9194, 3925, 2108, -467, -606, 3315, -2054, 3379, -600, 27, -3504, 1038, -1067], [8028, -1193, 3307, 1554, -287, -1064, -789, -2714, -817, 874, -1833, 2054, -67, 224, 984, -113], [29331, -271, -3149, 9763, 2168, 2074, 286, 1406, 4814, -3632, 145, -2796, -1255, -797, -2875, 407], [-5352, -3294, -6316, 3918, 764, -2736, 3430, -1293, -3434, -1777, -439, 207, -1072, -1117, 361, -929], [15795, -316, -20734, 8834, 1787, 1517, -198, -980, -868, 145, 1157, -1709, -1298, 1313, 747, -926], [-329, -1386, -2002, 372, 113, 262, 1376, 105, -1716, 2084, 336, 694, -795, 220, -33, 1627], [14870, 1216, -86, -2991, 1429, -425, 1718, -1251, 785, 82, 1790, -1453, 3433, -871, 1360, 3817], [-14470, 1863, -379, 3000, 496, 328, -619, 127, -45, -701, -502, -1721, 531, -1057, -1451, -74], [-5724, -2423, 7965, -1557, -1858, 2123, -1316, -1210, -3824, 3618, 820, 1744, 308, 1107, 2474, -799], [-64519, 2153, -6021, -2100, 212, -326, -439, -1259, -173, 1482, -1179, 1405, 1210, 364, 37, -1824], [8648, -671, 13053, -2437, -2032, -1350, -757, -1802, -3643, 3360, 1012, 2188, 2362, 357, 851, -613], [-51116, -704, -777, 7744, 718, 1653, -418, -348, 2707, 8, 3140, 257, 2013, 346, 2824, 1169]]
